netapp_ontap.models.switch_monitoring API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.switch_monitoring`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class SwitchMonitoringSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the SwitchMonitoring object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `enabled GET POST PATCH`

    Enable Health Monitoring.

  `monitored GET`

    Is Monitored.

  `reason GET`

    Reason For Not Monitoring.

    Valid choices:

    - none
    - unsupported_model
    - user_deleted
    - bad_ip_address
    - invalid_snmp_settings
    - bad_model
    - invalid_software_version
    - user_disabled
    - unknown